package net.locusworks.common.objectmapper;

/**
 * Holds the results from the object mapper list conversion
 * @author Isaac Parenteau
 * @version 1.0.0
 * @date 02/15/2018
 * @param <T> class type of the object being converted from json to object
 */
public class ObjectMapperResults<T> {
  
  private Throwable exception;
  private T results;
  
  /**
   * Constructor 
   * @param results results from the conversion
   */
  public ObjectMapperResults(T results) {
    this(results, null);
  }
  
  /**
   * Constructor
   * @param exception exception that was thrown during conversion
   */
  public ObjectMapperResults(Throwable exception) {
    this(null, exception);
  }
  
  /**
   * Constructor
   * @param results results from the conversion
   * @param exception exception that was thrown during conversion
   */
  public ObjectMapperResults(T results, Throwable exception) {
    this.results = results;
    this.exception = exception;
  }

  /**
   * get the exception that happened during conversion
   * @return exception
   */
  public Throwable getException() {
    return exception;
  }

  /**
   * Set the exception 
   * @param exception
   */
  public void setException(Throwable exception) {
    this.exception = exception;
  }

  /**
   * Get the result
   * @return the converted results
   */
  public T getResults() {
    return results;
  }

  /**
   * set the results
   * @param results results to set
   */
  public void setResults(T results) {
    this.results = results;
  }
  
  /**
   * Check to see if the conversion caused an error
   * @return true if there is an error, false otherwise
   */
  public boolean hasError() {
    return this.exception != null;
  }
  
  /**
   * Add the error handler to the results to retrieve the error that caused
   * the exception
   * @param error the error handler to use
   * @return this
   */
  public ObjectMapperResults<T> withErrorHandler(ObjectMapperError error) {
    if (this.hasError() && error != null) {
      error.getError(this.getException());
    }
    return this;
  }
}
